==================
Computational grid
==================

Sub-commands to support the computational grid components

.. autosummary::
   :nosignatures:
   :toctree: _generated/

   rompy_swan.subcomponents.startup.CARTESIAN
   rompy_swan.subcomponents.startup.SPHERICAL
